Coin Metrics API for Python
===========================
[![Documentation Status](https://readthedocs.org/projects/coinmetrics/badge/?version=latest)](https://coinmetrics.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/h4110w33n/coinmetrics.svg?branch=master)](https://travis-ci.org/h4110w33n/coinmetrics)
[![PyPI version](https://badge.fury.io/py/coinmetrics.svg)](https://badge.fury.io/py/coinmetrics)

An unofficial Python module for interacting with the Coin Metrics (coinmetrics.io) API. Currently, this library only impliments the [Community API](https://coinmetrics.io/api/). The [Pro APIs](https://coinmetrics.io/cm-network-data-pro/) will be available in a later release.

### Getting Started

This project's official documentation is hosted on [Read the Docs](https://coinmetrics.readthedocs.io/en/latest/index.html). Below are some direct links to get you started.

* [Install](https://coinmetrics.readthedocs.io/en/latest/install.html)
* [API Reference](https://coinmetrics.readthedocs.io/en/latest/api_ref.html)
* [Usage](https://coinmetrics.readthedocs.io/en/latest/usage.html)

### Donations

Like this project? Help fund others like it.

* __BTC:__ bc1qf523ue5xdzxqpgt4nnmpj78d2snzqf3n7s0rmd
* __USD:__ [PayPal Donation](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=NBK3S2YT92NVJ&currency_code=USD&source=url)